@@ -10,10 +10,10 @@
 #' @param  TSextra =NA, list provided to TS
 #' @param  alpha =0.05, the level of the hypothesis test 
 #' @param  Range  =c(-Inf, Inf) limits of possible observations, if any
-#' @param  B =c(1000, 1000), number of simulation runs to find power and null distribution
+#' @param  B =1000 number of simulation runs
 #' @param  nbins =c(100,10), number of bins for chi square tests.
 #' @param  rate =0 rate of Poisson if sample size is random, 0 if sample size is fixed
-#' @param  maxProcessors maximum of number of processors to use, 1 if no parallel processing is needed or number of cores-1 if missing
+#' @param  maxProcessor maximum of number of processors to use, 1 if no parallel processing is needed or number of cores-1 if missing
 #' @param  minexpcount =5 minimal expected bin count required
 #' @param  ChiUsePhat = TRUE, if TRUE param is estimated parameter, otherwise minimum chi square method is used.
 #' @return A numeric matrix of power values.
@@ -25,7 +25,7 @@
 #' rnull = function()  rnorm(50)
 #' ralt = function(mu)  rnorm(50, mu)
 #' TSextra = list(qnull=function(x) qnorm(x))
-#' gof_power(pnull, NA, rnull, ralt, c(0.25, 0.5), TSextra=TSextra, B=c(500, 500))
+#' gof_power(pnull, NA, rnull, ralt, c(0.25, 0.5), TSextra=TSextra, B=200)
 #' # Power of tests when null hypothesis specifies normal distribution and 
 #' # mean and standard deviation are estimated from the data. 
 #' # Example is not run because it takes several minutes.
@@ -35,15 +35,14 @@
 #' phat = function(x) c(mean(x), sd(x))
 #' TSextra = list(qnull = function(x, p=c(0, 1)) qnorm(x, p[1],  
 #'                ifelse(p[2]>0.001, p[2], 0.001))) 
-#' \donttest{gof_power(pnull, NA, rnull, ralt, c(0, 1), phat=phat, TSextra=TSextra, 
-#'           B=c(200, 200), maxProcessor=2)}
+#' gof_power(pnull, NA, rnull, ralt, c(0, 1), phat=phat, TSextra=TSextra, B=200)
 #' # Power of tests when null hypothesis specifies Poisson rv with rate 100 and 
 #' # true rate is 100.5
 #' vals = 0:250
 #' pnull = function() ppois(0:250, 100)
 #' rnull =function () table(c(0:250, rpois(1000, 100)))-1
 #' ralt =function (p) table(c(0:250, rpois(1000, p)))-1
-#' gof_power(pnull, vals, rnull, ralt, param_alt=100.5,  B=c(500,500))
+#' gof_power(pnull, vals, rnull, ralt, param_alt=100.5,  B=200)
 #' # Power of tests when null hypothesis specifies a Binomial n=10 distribution 
 #' # with the success probability estimated
 #' vals = 0:10
@@ -51,30 +50,37 @@
 #' rnull=function(p) table(c(0:10, rbinom(1000, 10, ifelse(0<p&p<1, p, 0.001))))-1
 #' ralt=function(p) table(c(0:10, rbinom(1000, 10, p)))-1
 #' phat=function(x) mean(rep(0:10,x))/10
-#' \donttest{gof_power(pnull, vals, rnull, ralt, c(0.5, 0.6), phat=phat,
-#'                     B=c(200, 200), maxProcessor=2)}
+#' gof_power(pnull, vals, rnull, ralt, c(0.5, 0.6), phat=phat, B=200)
 #'
 gof_power=function(pnull, vals=NA, rnull, ralt, param_alt, 
         w=function(x) -99, phat=function(x) -99, TS, TSextra=NA, 
-        alpha=0.05, Range  =c(-Inf, Inf), B=c(1000, 1000),nbins=c(50,10), 
-        rate=0, maxProcessors, minexpcount=5.0, ChiUsePhat=TRUE) {
+        alpha=0.05, Range  =c(-Inf, Inf), B=1000,nbins=c(50,10), 
+        rate=0, maxProcessor, minexpcount=5.0, ChiUsePhat=TRUE) {
   
-  if(missing(maxProcessors)) m=parallel::detectCores()-1
-  else m=maxProcessors
+  if(missing(maxProcessor)) {
+     if(!is.na(vals[1])) {
+        maxProcessor=1
+        message("For discrete data only a single processor is used if maxProcessor is not specified")
+     }
+     else  {
+       maxProcessor=parallel::detectCores(logical=FALSE)-1
+       message(paste("Using ",maxProcessor," cores.."))
+     }   
+  }   
   x = ralt(param_alt[1]) # get an example data set
   # adjust number of bins to account for parameter estimation
-  if(abs(phat(x)[1]+99)<0.001) nbins=nbins+length(phat(x)) 
+  if(abs(phat(x)[1]+99)>0.001) nbins=nbins+length(phat(x)) 
   if(any(is.na(vals))) { # continuous data/model
     check.functions(pnull, rnull, phat,  x=x) # do some sanity checks
     if(missing(TS)) # use built-in tests
         out = gof_power_cont(pnull, rnull, ralt, param_alt, w, phat,  
                          TSextra=TSextra, alpha=alpha, Range=Range, B=B, 
-                         nbins=nbins, rate=rate, maxProcessors=maxProcessors, 
+                         nbins=nbins, rate=rate, maxProcessor=maxProcessor, 
                          minexpcount=minexpcount, ChiUsePhat=ChiUsePhat)
     else # do user-provided tests
        out = gof_power_cont(pnull, rnull, ralt, param_alt, w, phat,  TS=TS,
                            TSextra=TSextra, alpha=alpha, Range=Range, B=B, 
-                           nbins=nbins, rate=rate, maxProcessors=maxProcessors, 
+                           nbins=nbins, rate=rate, maxProcessor=maxProcessor, 
                            minexpcount=minexpcount, ChiUsePhat=ChiUsePhat)  
   }
   else { # discrete data
@@ -83,14 +89,14 @@ gof_power=function(pnull, vals=NA, rnull, ralt, param_alt,
       out = gof_power_disc(pnull, rnull, vals, ralt, param_alt, phat,  
                            TSextra=TSextra, alpha=alpha, B=B, 
                            nbins=nbins, rate=rate, 
-                           maxProcessors=maxProcessors, 
+                           maxProcessor=maxProcessor, 
                            minexpcount=minexpcount,
                            ChiUsePhat=ChiUsePhat)
     else
       out = gof_power_disc(pnull, rnull, vals, ralt, param_alt, phat,  TS=TS,
                            TSextra=TSextra, alpha=alpha, B=B, 
                            nbins=nbins, rate=rate, 
-                           maxProcessors=maxProcessors, 
+                           maxProcessor=maxProcessor, 
                            minexpcount=minexpcount,
                            ChiUsePhat=ChiUsePhat)     
   }
